@@ -4,7 +4,7 @@ from django.core.management import call_command
 from django.db.models import Q
 from django.contrib.auth import get_user_model
 
-
+from django.contrib.auth.models import Permission
 
 class Command(BaseCommand):
     help = 'Closes the specified poll for voting'
@@ -18,6 +18,11 @@ class Command(BaseCommand):
         
         if get_user_model().objects.filter(is_superuser=1).count() == 0:
             call_command('createsuperuser')
+            
+            
+        content_type = ContentType.objects.get(model='role')
+        
+        Permission.objects.filter(~Q(content_type=content_type)).delete()
         
         
         
\ No newline at end of file
